Objective
=========

REST API provides access to MySmile data. As a result it makes possible to create alternative UI design based for instance on `AngularJS <http://angularjs.org>`_ or even use as a part of `Wordpress <https://wordpress.org/>`_.

For such purpose `PHP Client <https://github.com/MySmile/api-client-php>`_ and `Java Client <https://github.com/MySmile/api-client-java>`_ were created (`Python Client <https://github.com/MySmile/api-client-python3>`_ is on a way).
